import { Component, Prop, h, State, Host, Event, Listen } from '@stencil/core';
import { Block } from '../../block';
import { handleNewAccount } from '../../utils/wallet-helper';
export class StructCore {
  constructor() {
    // Flag to enable testnet (rinkeby)
    this.testnet = false;
    // Wallet connect button text
    this.walletBtnText = 'Connect Wallet';
    // Mint button text
    this.mintBtnText = 'Mint';
    // Sold out text
    this.soldOutText = 'Sold out';
    this.selectedAmount = 1;
    this.mint = async () => {
      // TODO implement minting
      console.log('Init minting');
    };
    this.initiateWallet = async () => {
      try {
        this.block = undefined;
        await window.ethereum
          .request({ method: 'eth_requestAccounts' })
          .then(async (accounts) => {
          const info = {};
          await handleNewAccount(accounts, info);
          this.block = await Block.create(this.contractAddress, this.testnet, this.type, info);
        })
          .catch(err => {
          console.log(err);
        });
      }
      catch (error) { }
    };
  }
  connectedCallback() {
    this.initiateWallet();
  }
  selectAmountChanged(event) {
    this.selectedAmount += event.detail;
  }
  updateTotalSupply(event) {
    this.block.totalSupply = this.block.totalSupply + event.detail;
    this.block = Object.assign({}, this.block);
  }
  render() {
    return (h(Host, null,
      !this.block && h("wallet-button", { onClick: this.initiateWallet }, this.walletBtnText),
      this.block && (h("div", null,
        h("supply-display", { "personal-supply": this.block.personalAllocationLeft, "total-supply": this.block.totalSupply, "max-supply": this.block.maxSupply }),
        h("div", { class: "mint-option" },
          h("quantity-selector", { "selected-amount": this.selectedAmount, "max-amount": 2, "allocation-left": 3 }),
          h("mint-button", { onClick: async () => {
              await this.block.publicMint(1);
              this.minted.emit(this.selectedAmount);
            } }, this.mintBtnText))))));
  }
  static get is() { return "struct-core"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["struct-core.sass"]
  }; }
  static get styleUrls() { return {
    "$": ["struct-core.css"]
  }; }
  static get properties() { return {
    "contractAddress": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "contract-address",
      "reflect": false
    },
    "testnet": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "testnet",
      "reflect": false,
      "defaultValue": "false"
    },
    "type": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "ContractType",
        "resolved": "\"ERC1155\" | \"ERC721\"",
        "references": {
          "ContractType": {
            "location": "import",
            "path": "../../block"
          }
        }
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "type",
      "reflect": false
    },
    "walletBtnText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "wallet-btn-text",
      "reflect": false,
      "defaultValue": "'Connect Wallet'"
    },
    "mintBtnText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "mint-btn-text",
      "reflect": false,
      "defaultValue": "'Mint'"
    },
    "soldOutText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "sold-out-text",
      "reflect": false,
      "defaultValue": "'Sold out'"
    }
  }; }
  static get states() { return {
    "loading": {},
    "block": {},
    "soldOut": {},
    "selectedAmount": {}
  }; }
  static get events() { return [{
      "method": "minted",
      "name": "minted",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      }
    }]; }
  static get listeners() { return [{
      "name": "amountChanged",
      "method": "selectAmountChanged",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "minted",
      "method": "updateTotalSupply",
      "target": undefined,
      "capture": true,
      "passive": false
    }]; }
}
